summaryrefslogtreecommitdiff
path: root/arch/mips/pmc-sierra/yosemite/smp.c
diff options
context:
space:
mode:
authorStephen Rothwell <sfr@canb.auug.org.au>2008-12-29 12:53:40 +1100
committerStephen Rothwell <sfr@canb.auug.org.au>2008-12-29 12:53:40 +1100
commitc02508b90e7d0832b9faf4d2e3e78364965c2133 (patch)
tree4400fa0bb906bd7f56f28b9062e8bed08ee7dbdf /arch/mips/pmc-sierra/yosemite/smp.c
parent3d74ad5cbcad2434b3b1530f633082b2df410d83 (diff)
parent918b43547f438ae800284623ae960362f3d4ae98 (diff)
Merge commit 'cpus4096/auto-cpus4096-next'
Diffstat (limited to 'arch/mips/pmc-sierra/yosemite/smp.c')
-rw-r--r--arch/mips/pmc-sierra/yosemite/smp.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/arch/mips/pmc-sierra/yosemite/smp.c b/arch/mips/pmc-sierra/yosemite/smp.c
index 3a7df647ca77..f78c29b68d77 100644
--- a/arch/mips/pmc-sierra/yosemite/smp.c
+++ b/arch/mips/pmc-sierra/yosemite/smp.c
@@ -141,7 +141,7 @@ static void __cpuinit yos_boot_secondary(int cpu, struct task_struct *idle)
}
/*
* Detect available CPUs, populate phys_cpu_present_map before smp_init
*
* We don't want to start the secondary CPU yet nor do we have a nice probing
* feature in PMON so we just assume presence of the secondary core.
@@ -150,10 +150,10 @@ static void __init yos_smp_setup(void)
{
int i;
- cpus_clear(phys_cpu_present_map);
+ cpus_clear(cpu_possible_map);
for (i = 0; i < 2; i++) {
- cpu_set(i, phys_cpu_present_map);
+ cpu_set(i, cpu_possible_map);
__cpu_number_map[i] = i;
__cpu_logical_map[i] = i;
}
@@ -141,7 +141,7 @@ static void __cpuinit yos_boot_secondary(int cpu, struct task_struct *idle)
}
/*
- * Detect available CPUs, populate phys_cpu_present_map before smp_init
+ * Detect available CPUs, populate cpu_possible_map before smp_init
*
* We don't want to start the secondary CPU yet nor do we have a nice probing